import { EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
import * as i0 from "@angular/core";
export declare type FileUploadErrorType = 'empty' | 'fileSize' | 'fileType';
export declare class DokuUploadFileComponent implements OnChanges {
    readonly size1MB = 1048576;
    id: string;
    title: string;
    subtitle?: string | null;
    /**
     * Sets a comma-separated list of content types.
     * It's the same attribute as in HTML input tag.
     *
     * See content/mime types reference
     * @link
     * https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types/Common_types
     */
    accept: HTMLInputElement['accept'];
    /**
     * The value is in MB.
     * Default max file size is 5MB.
     */
    maxSize: number;
    /**
     * Initial value of the file.
     *
     * It could be a type of:
     * - `File`, this type commonly used after choosing a file from file picker.
     * - `string`, the initial file could be a URL.
     */
    initialFile?: string | File;
    /**
     * Whether the field is invalid or not.
     * The field background will gonna be red if invalid.
     */
    invalid: boolean;
    onUpload: boolean;
    /**
     * Whether the file is remove-able.
     * Default to `true`.
     */
    removeAble: boolean;
    /**
     * Whether the file upload input is disabled.
     * Default to `false`.
     */
    disabled: boolean;
    /**
      * preview image will show or not.
      * Default to `true`.
      */
    showImage: boolean;
    /**
    * title will be dynamic if true.
    * Default to `true`.
    */
    dynamicTitle: boolean;
    canDownloadFile: boolean;
    fileChange: EventEmitter<File>;
    fileViewer: EventEmitter<any>;
    fileRemove: EventEmitter<void>;
    fileError: EventEmitter<FileUploadErrorType>;
    lang: string;
    loading: boolean;
    imagePreviewSrc: string | null;
    private file;
    ngOnChanges(changes: SimpleChanges): void;
    get isFileExist(): boolean;
    get isImage(): boolean;
    constructor();
    ngAfterViewInit(): void;
    onResize(): void;
    onPreviewImage(element: HTMLInputElement): void;
    onFileChange(event: Event): void;
    onFileDropped(fileList: FileList): void;
    onFileRemove(event: Event): void;
    nameFile: string;
    private handleFileChange;
    private showFilePreview;
    private showImagePreview;
    private checkFileIsImage;
    private validateFileSizeLimit;
    private validateFileType;
    static ɵfac: i0.ɵɵFactoryDeclaration<DokuUploadFileComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DokuUploadFileComponent, "doku-upload-file", never, { "id": "id"; "title": "title"; "subtitle": "subtitle"; "accept": "accept"; "maxSize": "maxSize"; "initialFile": "initialFile"; "invalid": "invalid"; "onUpload": "onUpload"; "removeAble": "removeAble"; "disabled": "disabled"; "showImage": "showImage"; "dynamicTitle": "dynamicTitle"; "canDownloadFile": "canDownloadFile"; }, { "fileChange": "fileChange"; "fileViewer": "fileViewer"; "fileRemove": "fileRemove"; "fileError": "fileError"; }, never, ["[status]"], false>;
}
